clear
set maxobs 30000
     
*----create a variable for household size

use \stata\vietnam\sect01a

*---drop non-members
keep if memb==1
keep screenid hid
collapse screenid, by(hid) count(hhsize)

label variable hhsize "Household size"
sum hhsize, d
save hhsize, replace
clear

set maxobs 5000
*----merge all household-level expenditure files to obtain total expenditures
use totfoodx
sort hid
merge hid using totnfdx1
tab _merge
drop _merge
sort hid
merge hid using totnfdx2
tab _merge
/* replace totnfdx2 = 0 if _merge == 1  */
drop _merge
sort hid
merge hid using educnexp
tab _merge
drop _merge
sort hid
merge hid using hlthexp
tab _merge
drop _merge
sort hid
merge hid using housexp
tab _merge
drop _merge
sort hid
merge hid using totinkx
tab _merge
/*
replace inkndexp= 0 if _merge == 1
replace lunchexp= 0 if _merge == 1
*/
drop _merge
sort hid
merge hid using rentexp
tab _merge
drop _merge
sort hid
merge hid using dointrvw
tab _merge
drop _merge
sort hid
merge hid using hhsize
tab _merge
drop _merge


*---add inkind wages in the form of lunch to total food expenditures
replace totfoodx=totfoodx+lunchexp if lunchexp~=.

*---sum all expenditures to obtain total nominal expenditures
#delimit ;
egen hhexpend=rsum(totfoodx totnfdx1 totnfdx2 educnexp hlthexp waterexp
		   garbexp elecexp inkndexp -lunchexp rentexp3);
#delimit cr
label variable hhexpend "Nominal HH expenditures-12m"


*----real expenditures (correction with regional deflators)
gen     realhhex=hhexpend/0.9692 if region==1 & urban==0
replace realhhex=hhexpend/1.0815 if region==1 & urban==1
replace realhhex=hhexpend/0.8954 if region==2 & urban==0
replace realhhex=hhexpend/1.0658 if region==2 & urban==1
replace realhhex=hhexpend/0.9813 if region==3 & urban==0
replace realhhex=hhexpend/1.0112 if region==3 & urban==1
replace realhhex=hhexpend/0.9764 if region==4 & urban==0
replace realhhex=hhexpend/1.0554 if region==4 & urban==1
replace realhhex=hhexpend/1.0638 if region==5
replace realhhex=hhexpend/1.2315 if region==6 & urban==1
replace realhhex=hhexpend/1.1153 if region==6 & urban==0
replace realhhex=hhexpend/1.0929 if region==7 & urban==1
replace realhhex=hhexpend/1.0196 if region==7 & urban==0
label variable realhhex "Real HH expenditures-12m"

*----real expenditures (correction with monthly deflators) 

replace realhhex = realhhex/0.9524 if year == 92 & month == 09
replace realhhex = realhhex/0.9507 if year == 92 & month == 10 
replace realhhex = realhhex/0.9699 if year == 92 & month == 11 
replace realhhex = realhhex/0.9833 if year == 92 & month == 12 
replace realhhex = realhhex/1.0190 if year == 93 & month == 02 
replace realhhex = realhhex/1.0139 if year == 93 & month == 03 
replace realhhex = realhhex/1.0119 if year == 93 & month == 04 
replace realhhex = realhhex/1.0271 if year == 93 & month == 05 
replace realhhex = realhhex/1.0240 if year == 93 & month == 06 
replace realhhex = realhhex/1.0240 if year == 93 & month == 07 
replace realhhex = realhhex/1.0219 if year == 93 & month == 08 
replace realhhex = realhhex/1.0270 if year == 93 & month == 09 
replace realhhex = realhhex/1.0260 if year == 93 & month == 10 

gen pcexpend=hhexpend/hhsize
label variable pcexpend "Nominal PC expenditures-12m"
gen realpcex=realhhex/hhsize
label variable realpcex "Real PC expenditures-12m"

sum hhexpend realhhex pcexpend realpcex,d

label data "Household expenditures: VNLSS"

sort realpcex
gen runsum=sum(hhsize)
gen int quintile=autocode(runsum,5,1,23839)
tab quintile
tab quintile [weight=hhsize]
replace quintile=1 if quintile<9000
replace quintile=2 if quintile>1 & quintile<10000
replace quintile=3 if quintile>2 & quintile<15000
replace quintile=4 if quintile>3 & quintile<20000
replace quintile=5 if quintile>4 
tab quintile [weight=hhsize], sum(pcexpend)

summ
save hhexpend, replace

