clear
set maxobs 130000 

*-----non-food expenditures - 4-week items 

use \stata\vietnam\sect12a

*-------non-food corrections - see VLSMS152
replace hhexpa=0.44 if hid==1704 & hhexpcd==104
replace hhexpa=2.1 if hid==20608 & hhexpcd==108
replace hhexpa=5 if hid==11919 & hhexpcd==110
replace hhexpa=2.5 if hid==11713 & hhexpcd==114
replace hhexpa=2.0 if hid==19616 & hhexpcd==114

*-----inflate 4-week values to annual values
gen xnfd12m=hhexpa*13

keep hid hhexpcd xnfd12m
save xnfd, replace

*------non-food expenditures - annual items

use \stata\vietnam\sect12b

*-------non-food corrections - see VLSMS152
replace hhexpaly=23 if hid==23007 & hhexpcd==130

*----these are consumer durables bought in the past year 
*    information on them is available in the section on consumer durables
drop if hid==18910 & hhexpcd==132
drop if hid==9205 & hhexpcd==132

replace hhexpaly=134 if hid==28318 & hhexpcd==138
replace hhexpaly=250 if hid==26601 & hhexpcd==160

sum
rename hhexpaly xnfd12m

*---appends 4-week (annualized) nonfood expenditure items
append using xnfd

tab hhexpcd

*----drop non-food expenditures that are not welfare-enhancing or
*    are reflected in the current value of consumer durables

drop if hhexpcd==113 | (hhexpcd>132 & hhexpcd<141) 
drop if (hhexpcd>151 & hhexpcd<156) | hhexpcd==158

rename hhexpcd expcode
keep hid expcode xnfd12m

save xnfd, replace

collapse xnfd12m, by(hid) sum(totnfdx1)
label variable totnfdx1 "Non-food exp - 4wk+12m"
sum totnfdx1, d
save totnfdx1, replace

*------non-food expenditures - consumer durables

use \stata\vietnam\sect12c

*-----consumer durable corrections 
replace goodacy=82 if hid==25320 & goodcd==202
replace goodcv=. if hid==27902 & goodcd==202 & line==2
replace goodacy=78 if hid==20015 & goodcd==203
replace goodcv=1450 if hid==19616 & goodcd==203
replace goodcv=1100 if hid==20809 & goodcd==205
replace goodcv=800 if hid==24712 & goodcd==218 & line==10
replace goodbuy=110  if hid==20813 & goodcd==207
replace goodbuy=1000 if hid==14817 & goodcd==224 

save nfdcdurb, replace
clear

*---Depreciation rates calculations

set maxobs 5000
use \stata\vietnam\sect00a
keep hid date1
gen svyyear=mod(date1,100)
gen svymonth=mod(int(date1/100),100)
tab svymonth svyyear,m
drop date1
sort hid
save svydate, replace
clear

set maxobs 32000 

use nfdcdurb
sort hid
merge hid using svydate
tab _merge
drop if _merge<3

*---these cds are producer durables
drop if hid==8716 & goodcd==219
drop if hid==8714 & goodcd==219
drop if hid==13011 & goodcd==216
drop if hid==25501 & goodcd==216

*----calculations based on acquisitions since 1985
keep if goodacy>85 & goodacy<94
drop if goodbuy==0 | goodbuy==.

*----generating an inflator variable to make all past values real : 1993=100

gen inflator=52423.1/321.1 if goodacy==86
replace inflator=52423.1/1514.4 if goodacy==87
replace inflator=52423.1/7181.7 if goodacy==88
replace inflator=52423.1/14059.7 if goodacy==89
replace inflator=52423.1/19177.9 if goodacy==90
replace inflator=52423.1/35038.2 if goodacy==91
replace inflator=52423.1/48240.7 if goodacy==92
replace inflator=52423.1/52423.1 if goodacy==93
gen realpurp=goodbuy*inflator

*---determining duration for which household has had cd
replace goodacm=svymon if goodacm==.
gen hadformn=(svyyear-goodacy)*12 + (svymon-goodacm)
sum hadformn,d
l hid goodacy goodacm svyyear svymon if hadformn<0
replace hadformn=0 if hadformn<0

gen depnrate=1-((goodcv/realpurp)^(1/(hadformn/12))) 
sum depnrate, d
tab goodcd, sum(depnrate)
sort goodcd

keep hid goodcd depnrate realpurp goodcv hadformn
save depnrate, replace

*-----calculate a median depreciation rate for each cd
collapse depnrate, by(goodcd) median(meddeprt)
sum meddeprt,d
sort goodcd
save meddepn, replace

*-------calculation of use value of consumer durable
use nfdcdurb
sort goodcd
merge goodcd using meddepn
drop _merge

*---these cds are producer durables
drop if hid==8716 & goodcd==219
drop if hid==8714 & goodcd==219
drop if hid==13011 & goodcd==216
drop if hid==25501 & goodcd==216

*-----assumes real interest rate of 5 %
gen xnfd12m=goodcv*(1+meddeprt)*(0.05+meddeprt)
sum xnfd12m,d 

rename goodcd expcode
keep hid expcode xnfd12m 

collapse xnfd12m, by(hid) sum(totnfdx2)
sum totnfdx2,d
label variable totnfdx2 "Consumer durable - use value"
sort hid
save totnfdx2, replace



