clear
set matsize 150
set maxobs 5000

use \stata\vietnam\sect06

*-----region & location variables

*----commune number
gen cum=round((int(hid/100)/2),1)
replace cum=68 if cum==151
label variable cum "Commune number"

*----dummy variables for Hanoi & Saigon
gen hanoi=cum>123 & cum<127
gen saigon=cum>138 & cum<145

gen byte urban=0 if 1<=cum&cum<=120
replace urban=1 if 121<=cum&cum<=150

gen int region=1 if (cum>=1&cum<=12)|(cum>=22&cum<=28)
replace region=1 if (cum>=121&cum<=123)|cum==127
replace region=2 if (cum>=13&cum<=21)|(cum>=29&cum<=51)
replace region=2 if cum>=124&cum<=130&cum~=127
replace region=3 if cum>=52&cum<=69
replace region=3 if cum==131|cum==132
replace region=4 if (cum>=70&cum<=79&cum~=73)|(cum>=82&cum<=84)
replace region=4 if cum>=133&cum<=137
replace region=5 if cum==73|cum==80|cum==81|cum==85
replace region=6 if (cum>=86&cum<=89)|(cum>=92&cum<=97)
replace region=6 if cum>=139&cum<=145
replace region=7 if cum==90|cum==91|(cum>=98&cum<=120)
replace region=7 if cum==138|(cum>=146&cum<=150)

label define region 1 "NU" 2 "RR" 3 "NC" 4 "NC" 5 "CH" 6 "SE" 7 "MD"
label values region region
label define urban 0 "Rural" 1 "Urban"
label values urban urban

tab region, gen(region)

gen electrcy=light==1

tab bultyear, gen(dwelage)
tab dwater, gen(dh2osrc)

tab walls, gen(walls)
tab floor, gen(floor)
tab roof, gen(roof)

*-----dummy variables for repair condition of dwelling
egen repair=group(dwlwcond dwlfcond dwlrcond)
#delimit ;
label define repair 1 "All3" 2 "W+F" 3 "W+R" 4 "Wall" 5 "F+R" 
                    6 "Floor" 7 "Roof" 8 "AllOk";
#delimit cr
label values repair repair

*----recode some categories to create dummy variables
replace light=5 if light==2
replace window=5 if window==3

tab door, gen(door)
tab window, gen(window)
tab toilet, gen(toilet)
tab repair, gen(repair)

gen roomgp=rooms
replace roomgp=5 if rooms>5
label variable roomgp "Room groups: > 5=5"
tab roomgp, gen(roomgp)

gen loghval=log(saleval)

#delimit ;
stepwise loghval dwelage2-dwelage6 roomgp2-roomgp5 electrcy 
         dh2osrc1-dh2osrc7 walls1-walls8 floor1-floor7 roof1-roof7 
         toilet2-toilet5 window2-window5 door2-door4 repair1-repair7 
         region2-region7 urban hanoi saigon uar lar, backward;
#delimit cr

predict lnhvalht
gen houseval=exp(lnhvalht)
replace houseval = saleval if hid == 27815  /* house with fifteen rooms */
label variable houseval "Predicted house value"

*----estimated rental expenditures - 2 and 3 percent (annually) of predicted
*    sale value of dwelling - multiplied by 1000 because sale value info in
*    millions of dongs

gen rentexp2=0.02*houseval*1000
gen rentexp3=0.03*houseval*1000
label variable rentexp2 "Imputed rent - interest rate=2%"
label variable rentexp3 "Imputed rent - interest rate=3%"
sum rentexp*, d

keep hid rentexp* saleval houseval region urban cum rentby vrentc rentuc
replace vrentc = vrentc * 2 if rentuc == 7
replace vrentc = vrentc * 4 if rentuc == 6
replace vrentc = vrentc * 12 if rentuc == 5
gen ratio_rs = vrentc/(1000 * saleval) if rentby == 3
label variable ratio_rs "Rent/Sale if rented from private agency" 
tab ratio_rs
drop rentby vrentc rentuc ratio_rs
sort hid
save rentexp, replace



